AndroidOptions class

Specific options for Android platform.

Inheritance
  • Object
  • Options
  • AndroidOptions

Constructors

AndroidOptions({@Deprecated('EncryptedSharedPreferences is deprecated and will be ' 'removed in v11. The Jetpack Security library is deprecated by Google. ' 'Your data will be automatically migrated to custom ciphers on first ' 'access. Remove this parameter - it will be ignored.') bool encryptedSharedPreferences = false, bool resetOnError = true, bool migrateOnAlgorithmChange = true, bool enforceBiometrics = false, KeyCipherAlgorithm keyCipherAlgorithm = KeyCipherAlgorithm.RSA_ECB_OAEPwithSHA_256andMGF1Padding, StorageCipherAlgorithm storageCipherAlgorithm = StorageCipherAlgorithm.AES_GCM_NoPadding, String? sharedPreferencesName, String? preferencesKeyPrefix, String? biometricPromptTitle, String? biometricPromptSubtitle})
Standard secure storage using AES-GCM with RSA OAEP key wrapping.
const
AndroidOptions.biometric({@Deprecated('EncryptedSharedPreferences is deprecated and will be removed in v11. ' 'The Jetpack Security library is deprecated by Google. ' 'Remove this parameter - it will be ignored.') bool encryptedSharedPreferences = false, bool resetOnError = true, bool migrateOnAlgorithmChange = true, bool enforceBiometrics = false, String? sharedPreferencesName, String? preferencesKeyPrefix, String? biometricPromptTitle, String? biometricPromptSubtitle})
Maximum security storage with optional biometric authentication.
const

Properties

biometricPromptSubtitle String?
The subtitle shown in the biometric authentication prompt.
final
biometricPromptTitle String?
The title shown in the biometric authentication prompt.
final
hashCode int
The hash code for this object.
no setterinherited
params Map<String, String>
A getter that retrieves the options as a map representation.
no setterinherited
preferencesKeyPrefix String?
The prefix for a shared preference key. The prefix is used to make sure the key is unique to your application. An underscore (_) is added to the end of the prefix automatically. If not provided, a default prefix will be used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedPreferencesName String?
The name of the sharedPreference database to use. You can select your own name if you want. A default name will be used if nothing is provided here.
final

Methods

copyWith({bool? encryptedSharedPreferences, bool? resetOnError, bool? migrateOnAlgorithmChange, bool? enforceBiometrics, KeyCipherAlgorithm? keyCipherAlgorithm, StorageCipherAlgorithm? storageCipherAlgorithm, String? preferencesKeyPrefix, String? sharedPreferencesName, String? biometricPromptTitle, String? biometricPromptSubtitle}) AndroidOptions
Creates a copy of this AndroidOptions with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String>
Converts the options into a map representation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultOptions → const AndroidOptions
Default Android options with standard secure configuration.