AppleButtonText enum

The type of Apple Sign-In button.

Inheritance
Available extensions

Values

signinWith → const AppleButtonText

The button text is "Sign in with Apple".

continueWith → const AppleButtonText

The button text is "Continue with Apple".

signupWith → const AppleButtonText

The button text is "Sign up with Apple".

signin → const AppleButtonText

The button text is "Sign in".

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppleButtonText>
A constant List of the values in this enum, in order of their declaration.