AppleSignInButton class

A styled button for Apple Sign-In.

This widget wraps the official Sign in with Apple button from the sign_in_with_apple package and adds loading and disabled states.

Inheritance

Constructors

AppleSignInButton({required VoidCallback? onPressed, required bool isLoading, required bool isDisabled, AppleButtonText type = AppleButtonText.continueWith, AppleButtonStyle style = AppleButtonStyle.black, AppleButtonSize size = AppleButtonSize.large, AppleButtonShape shape = AppleButtonShape.pill, AppleButtonLogoAlignment logoAlignment = AppleButtonLogoAlignment.center, double minimumWidth = 240, Key? key})
Creates an Apple Sign-In button.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisabled bool
Whether the button is disabled.
final
isLoading bool
Whether the button is currently loading.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
logoAlignment AppleButtonLogoAlignment
The Apple logo alignment: left or center.
final
minimumWidth double
The minimum button width, in pixels.
final
onPressed VoidCallback?
Callback when the button is pressed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape AppleButtonShape
The button shape.
final
size AppleButtonSize
The button size.
final
style AppleButtonStyle
The button style.
final
type AppleButtonText
The button type: icon, or standard button.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited