AuthIdpTheme class

Theme for the authentication identity provider UI.

Inheritance
Annotations

Constructors

AuthIdpTheme({required PinTheme defaultPinTheme, required PinTheme focusedPinTheme, required PinTheme errorPinTheme, required Widget separator})
Creates a new AuthIdpTheme.
const
AuthIdpTheme.defaultTheme({Color? borderColor, PinTheme? defaultPinTheme, PinTheme? focusedPinTheme, PinTheme? errorPinTheme, Widget? separator})
Creates a default AuthIdpTheme with optional overrides.
factory

Properties

defaultPinTheme PinTheme
The default pin input theme used for unselected/idle state.
final
errorPinTheme PinTheme
The pin input theme used to indicate an error state.
final
focusedPinTheme PinTheme
The pin input theme used when the field is focused.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separator Widget
The separator between pin input fields.
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({PinTheme? defaultPinTheme, PinTheme? focusedPinTheme, PinTheme? errorPinTheme, Widget? separator}) AuthIdpTheme
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<AuthIdpTheme>? other, double t) AuthIdpTheme
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited