toHeaderValue abstract method

Future<String?> toHeaderValue(
  1. String? key
)

Converts an authentication key to a format that can be used in a transport header. This will automatically be unwrapped again on the server side before being handed to the authentication handler.

The value must be compliant with the HTTP header format defined in RFC 9110 HTTP Semantics, 11.6.2. Authorization. See: https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Authorization https://httpwg.org/specs/rfc9110.html#field.authorization

Implementation

Future<String?> toHeaderValue(String? key);