startPasswordReset method

Future<void> startPasswordReset()

Starts the password reset process.

Sends a password reset email to the provided email address. On success, transitions to password reset pending state. On failure, transitions to error state with the error message.

Implementation

Future<void> startPasswordReset() async {
  await _guarded(null, EmailFlowScreen.verifyPasswordReset, () async {
    final email = emailController.text.trim();
    _requestId = await _emailEndpoint.startPasswordReset(email: email);
  });
}