verificationCodeConfig property
Configuration for the verification code input.
Make sure to match the configuration of the code generated by the server.
Implementation
final VerificationCodeConfig verificationCodeConfig;
Configuration for the verification code input.
Make sure to match the configuration of the code generated by the server.
final VerificationCodeConfig verificationCodeConfig;