MicrosoftSignInStyle class

The style configuration for the Microsoft Sign-In button.

Constructors

MicrosoftSignInStyle({required Size size, required Color foregroundColor, required Color backgroundColor, required BorderRadius borderRadius})
Creates a MicrosoftSignInStyle with the given properties.
const
MicrosoftSignInStyle.fromConfiguration({required MicrosoftButtonShape shape, required MicrosoftButtonSize size, required MicrosoftButtonStyle style, required double width})
Creates a MicrosoftSignInStyle from button configuration.
factory

Properties

backgroundColor Color
The background color of the button.
final
borderRadius BorderRadius
The border radius of the button.
final
borderSide BorderSide
Gets the border side for the button.
no setter
foregroundColor Color
The foreground color (text and icon).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
The size of the button.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited