BasicSignInTexts class
Texts for basic sign-in UI elements.
- Annotations
Constructors
- BasicSignInTexts({required String noAuthenticationProvidersConfigured, required String orContinueWith})
-
Creates a new BasicSignInTexts configuration.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- noAuthenticationProvidersConfigured → String
-
Message shown when no identity provider is available on the server.
final
- orContinueWith → String
-
Text shown in the divider above social sign-in options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? noAuthenticationProvidersConfigured, String? orContinueWith}) → BasicSignInTexts - Creates a copy of this object with updated values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- defaults → const BasicSignInTexts
- Default English texts.