GitHubSignInResult typedef
Result of the GitHub OAuth sign-in flow.
Contains the authorization code and PKCE code verifier that must be sent to your backend endpoint to complete authentication.
Implementation
typedef GitHubSignInResult = ({
/// The authorization code received from GitHub after user authorization.
String code,
/// The PKCE code verifier that was used to generate the code challenge.
/// Must be sent to the backend along with the code for token exchange.
String codeVerifier,
/// The redirect URI that was used for the OAuth flow.
/// Must be sent to the backend along with the code for token exchange.
String redirectUri,
});