PasswordRequirementTexts class
Localized strings for password rule labels (e.g. minimum length, character classes).
- Annotations
Constructors
- PasswordRequirementTexts({required String minLengthTemplate, required String maxLengthTemplate, required String containsLowercase, required String containsUppercase, required String containsNumber, required String containsSpecialCharacter})
-
Creates PasswordRequirementTexts.
const
Properties
- containsLowercase → String
-
Label when the password must contain a lowercase letter.
final
- containsNumber → String
-
Label when the password must contain a digit.
final
- containsSpecialCharacter → String
-
Label when the password must contain a special character.
final
- containsUppercase → String
-
Label when the password must contain an uppercase letter.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxLengthTemplate → String
-
Template for maximum length. Use
{length}as a placeholder.final - minLengthTemplate → String
-
Template for minimum length. Use
{length}as a placeholder.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? minLengthTemplate, String? maxLengthTemplate, String? containsLowercase, String? containsUppercase, String? containsNumber, String? containsSpecialCharacter}) → PasswordRequirementTexts - Creates a copy with the given fields replaced.
-
maxLength(
int length) → String - Localized description for a maximum length rule using maxLengthTemplate.
-
minLength(
int length) → String - Localized description for a minimum length rule using minLengthTemplate.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- defaults → const PasswordRequirementTexts
- Default English strings.