UserProfileImage class abstract
Database entity for storing user profile image information.
- Implemented types
Constructors
- UserProfileImage({UuidValue? id, required UuidValue userProfileId, UserProfile? userProfile, DateTime? createdAt, required String storageId, required String path, required Uri url})
-
factory
-
UserProfileImage.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- createdAt ↔ DateTime
-
The time when this profile image was created.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ UuidValue?
-
The database id, set if the object has been inserted into the
database or if it has been fetched from the database. Otherwise,
the id will be null.
getter/setter pair
- path ↔ String
-
Path inside storageId at which the image is stored.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageId ↔ String
-
Storage in which the image is stored.
getter/setter pair
- url ↔ Uri
-
The public URL to access the image.
getter/setter pair
- userProfile ↔ UserProfile?
-
The UserProfile this image belongs to.
getter/setter pair
- userProfileId ↔ UuidValue
-
getter/setter pair
Methods
-
copyWith(
{UuidValue? id, UuidValue? userProfileId, UserProfile? userProfile, DateTime? createdAt, String? storageId, String? path, Uri? url}) → UserProfileImage - Returns a shallow copy of this UserProfileImage with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited